==> package-manager-1.99.1.tar.gz: package-manager-1.99.1/setup/parse-conflicts.c <==
#include <fstab.h>
#include <dirent.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <badpenguin-ansi.h>
#include <badpenguin-errors.h>
#include <badpenguin-chain.h>
#include <badpenguin-fs.h>

#include "parse-info.h"
#include "parse-options.h"
#include "setup-quit.h"


int parse_conflicts(){
  char conflictName[255], cmdline[255];
  char *p, *l;
  int i, retval;
  DIR *lpdir;
  struct dirent *lpstdirent;
  
  // Parsing conflicts
  p = gostPackageInfo.conflicts;
  while (p[0]!=0) {
    // skip blanks 
    while (p[0]==' ') p++;
    // search for ':'    
    l=p;
    while ((l[0]!=' ')&&(l[0]!=0)) l++;
    i=l-p;    
    strncpy( conflictName, p, i );
    conflictName[i]=0;
    p=l;
    // cerca directory
    if (gostOptions.verbose>2) printf("- conflicts : %s \n", conflictName );
    lpdir = opendir( gostOptions.spoolroot );
    if (lpdir==NULL) {
      printERROR("! impossibile aprire %s\n", gostOptions.spoolroot );
      normal_color();
      setup_quit(ERROR_IO);
    }
    lpstdirent = readdir(lpdir);
    while (lpstdirent!=NULL) {    
      if (
        ( 0 == strncmp(lpstdirent->d_name, conflictName, strlen(conflictName)) ) &&
	( 0 == is_directory(gostOptions.spoolroot,lpstdirent->d_name) )
      ) {
        strcpy(cmdline, gostOptions.spoolroot);
	strcat(cmdline,"/");
	strcat(cmdline,lpstdirent->d_name);
	//printf("lstat: %s\n", cmdline);
        if (gostOptions.verbose>0) printf("> rimuovo il pacchetto in conflitto: %s \n",lpstdirent->d_name);
        sprintf(cmdline, "package-setup --no-header --remove %s %s", lpstdirent->d_name, gostOptions.targetdir );
        if (gostOptions.verbose>0) printf("- eseguo: %s\n", cmdline);
	printf("[ removing %s ]----------\n", lpstdirent->d_name );
        retval = runshell(cmdline);
	printf("----------------------------------------------------------------------\n");
        chdir(gostOptions.targetdir);
      }
      lpstdirent = readdir(lpdir);
    }
    closedir(lpdir);
    // NEXT
  }
  return 0;
}

==> package-manager-1.99.4.tar.gz: package-manager-1.99.4/setup/parse-conflicts.c <==
#include <fstab.h>
#include <dirent.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <badpenguin-ansi.h>
#include <badpenguin-errors.h>
#include <badpenguin-chain.h>
#include <badpenguin-fs.h>

#include "parse-info.h"
#include "parse-options.h"
#include "setup-quit.h"


int parse_conflicts(){
  char conflictName[255], cmdline[255];
  char *p, *l;
  int i, retval;
  DIR *lpdir;
  struct dirent *lpstdirent;
  
  // Parsing conflicts
  p = gostPackageInfo.conflicts;
  while (p[0]!=0) {
    // skip blanks 
    while (p[0]==' ') p++;
    // search for ':'    
    l=p;
    while ((l[0]!=' ')&&(l[0]!=0)) l++;
    i=l-p;    
    strncpy( conflictName, p, i );
    conflictName[i]=0;
    p=l;
    // cerca directory
    if (gostOptions.verbose>2) printf("- conflicts : %s \n", conflictName );

    lpdir = opendir( gostOptions.spoolroot );
    if (lpdir==NULL) {
      printERROR("! impossibile aprire %s\n", gostOptions.spoolroot );
      normal_color();
      setup_quit(ERROR_IO);
    }
    lpstdirent = readdir(lpdir);
    while (lpstdirent!=NULL) {    
      if (
        ( 0 == strncmp(lpstdirent->d_name, conflictName, strlen(conflictName)) ) &&
	( 0 == is_directory(gostOptions.spoolroot,lpstdirent->d_name) )
      ) {

	if ( 0 == strcmp(gostPackageInfo.fullname, lpstdirent->d_name) ) {
          printWARNING("! il pacchetto %s e' gia' installato\n",lpstdirent->d_name);
	  normal_color();
	  // If we use FORCE do not exist!
	  if ( gostOptions.force != 1 ) {
	    setup_quit(ERROR_EXISTING);
	  }
	}

        strcpy(cmdline, gostOptions.spoolroot);
	strcat(cmdline,"/");
	strcat(cmdline,lpstdirent->d_name);
        if (gostOptions.verbose>0) printf("> rimuovo il pacchetto in conflitto: %s \n",lpstdirent->d_name);
        sprintf(cmdline, "package-setup --no-header --remove  %s  %s", lpstdirent->d_name, gostOptions.targetdir );
        if (gostOptions.verbose>0) printf("- eseguo: %s\n", cmdline);
	printf("/----- removing %s -----\\\n", lpstdirent->d_name );
        retval = runshell(cmdline);
	printf("\\----- removed  %s -----/\n", lpstdirent->d_name );
        chdir(gostOptions.targetdir);
      }
      lpstdirent = readdir(lpdir);
    }
    closedir(lpdir);
    // NEXT
  }
  return 0;
}
